summaryrefslogtreecommitdiff
path: root/gtk2_ardour/midi_region_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/midi_region_view.h')
-rw-r--r--gtk2_ardour/midi_region_view.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/gtk2_ardour/midi_region_view.h b/gtk2_ardour/midi_region_view.h
index c2475f00fa..50cac66d77 100644
--- a/gtk2_ardour/midi_region_view.h
+++ b/gtk2_ardour/midi_region_view.h
@@ -164,7 +164,7 @@ class MidiRegionView : public RegionView
/**
* This function provides the snap function for region position relative coordinates
* for pixel units (double) instead of nframes_t
* @param x a pixel coordinate relative to region start
* @return the snapped pixel coordinate relative to region start
*/
@@ -172,18 +172,18 @@ class MidiRegionView : public RegionView
/**
* This function provides the snap function for region position relative coordinates
* for pixel units (double) instead of nframes_t
* @param x a pixel coordinate relative to region start
* @return the snapped nframes_t coordinate relative to region start
*/
- nframes_t snap_to_frame(double x);
+ nframes64_t snap_to_frame(double x);
/**
* This function provides the snap function for region position relative coordinates
* @param x a pixel coordinate relative to region start
* @return the snapped nframes_t coordinate relative to region start
*/
- nframes_t snap_to_frame(nframes_t x);
+ nframes64_t snap_to_frame(nframes64_t x);
protected:
@@ -164,7 +164,7 @@ class MidiRegionView : public RegionView
/**
* This function provides the snap function for region position relative coordinates
- * for pixel units (double) instead of nframes_t
+ * for pixel units (double) instead of nframes64_t
* @param x a pixel coordinate relative to region start
* @return the snapped pixel coordinate relative to region start
@@ -172,18 +172,18 @@ class MidiRegionView : public RegionView
/**
* This function provides the snap function for region position relative coordinates
- * for pixel units (double) instead of nframes_t
+ * for pixel units (double) instead of nframes64_t
* @param x a pixel coordinate relative to region start
@@ -172,18 +172,18 @@ class MidiRegionView : public RegionView
* @param x a pixel coordinate relative to region start
- * @return the snapped nframes_t coordinate relative to region start
+ * @return the snapped nframes64_t coordinate relative to region start
*/
@@ -172,18 +172,18 @@ class MidiRegionView : public RegionView
* This function provides the snap function for region position relative coordinates
* @param x a pixel coordinate relative to region start
- * @return the snapped nframes_t coordinate relative to region start
+ * @return the snapped nframes64_t coordinate relative to region start
*/